// Copyright (c) 2015, the package authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// MIT license that can be found in the LICENSE file.

part of dartiny_event_dispatcher;

/// Event is the base class for classes containing event data.
///
/// This class contains no event data. It is used by events that do not pass
/// state information to an event handler when an event is raised.
///
/// You can call the method [stopPropagation] to abort the execution of
/// further listeners in your event listener.
class Event {
  bool _propagationStopped = false;

  /// Whether no further event listeners should be triggered.
  bool get isPropagationStopped => _propagationStopped;

  /// Stops the propagation of the event to further event listeners.
  ///
  /// If multiple event listeners are connected to the same event, no
  /// further event listener will be triggered once any trigger calls
  /// stopPropagation().
  void stopPropagation() {
    _propagationStopped = true;
  }
}