// Copyright (c) 2015, the package authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// MIT license that can be found in the LICENSE file.

part of dartiny_event_dispatcher;

class EventDispatcherBuilder {

  Map<String, List<_EventSubscription>> _subscriptions = new Map<String, List<_EventSubscription>>();

  EventDispatcherBuilder() {
    _initSubscriptions();
  }

  void addListener(String eventName, EventListener listener, { int priority: 0}) {
    assert(eventName != null);
    assert(eventName.trim().isNotEmpty);
    assert(listener != null);
    assert(priority != null);

    if (!_subscriptions.containsKey(eventName)) {
      _subscriptions[eventName] = new List<_EventSubscription>();
    }

    _subscriptions[eventName].add(
      new _EventSubscription(listener, priority)
    );
  }

  EventDispatcher build() {
    _subscriptions.forEach((_, subscriptions) {
      subscriptions.sort((_EventSubscription a, _EventSubscription b) {
        return a.priority.compareTo(b.priority) * -1;
      });
    });

    var dispatcher = new EventDispatcher(_subscriptions);
    _initSubscriptions();

    return dispatcher;
  }

  void _initSubscriptions() {
    _subscriptions = new Map<String, List<_EventSubscription>>();
  }

}